order_cmd.c
changeset 1247 01711347f9ac
parent 1245 768d9bc95aaa
child 1266 9dc5638fe8cc
--- a/order_cmd.c	Mon Jan 31 11:03:23 2005 +0000
+++ b/order_cmd.c	Mon Jan 31 11:23:10 2005 +0000
@@ -136,9 +136,11 @@
 	if (v->num_orders >= 40)
 		return_cmd_error(STR_8832_TOO_MANY_ORDERS);
 
 	/* For ships, make sure that the station is not too far away from the previous destination. */
 	if (v->type == VEH_Ship && IS_HUMAN_PLAYER(v->owner) &&
-		sel != 0 && GetVehicleOrder(v, sel - 1)->type == OT_GOTO_STATION) {
+		sel != 0 && GetVehicleOrder(v, sel - 1)->type == OT_GOTO_STATION
+		&& !_patches.new_pathfinding_all) {
 
 		int dist = DistanceManhattan(
 			GetStation(GetVehicleOrder(v, sel - 1)->station)->xy,
@@ -136,9 +136,11 @@
 		return_cmd_error(STR_8832_TOO_MANY_ORDERS);
 
-	/* For ships, make sure that the station is not too far away from the previous destination. */
+	/* For ships, make sure that the station is not too far away from the
+	 * previous destination, for human players with new pathfinding disabled */
 	if (v->type == VEH_Ship && IS_HUMAN_PLAYER(v->owner) &&